@@ -1,24 +1,22 @@
 'use strict';
 
-var NQPObject = require('./nqp-object.js');
-var Null = require('./null.js');
+const NQPObject = require('./nqp-object.js');
+const Null = require('./null.js');
 
-let HashIter = require('./hash-iter.js');
-
-var repossession = require('./repossession.js');
-var compilingSCs = repossession.compilingSCs;
+const HashIter = require('./hash-iter.js');
 
+const sixmodel = require('./sixmodel.js');
 
 class Hash extends NQPObject {
   constructor() {
     super();
-    this._SC = undefined;
+    this.$$SC = undefined;
     this.content = new Map();
   }
 
   $$bindkey(key, value) {
     this.content.set(key, value);
-    if (this._SC !== undefined) this.$$scwb();
+    if (this.$$SC !== undefined) this.$$scwb();
     return value;
   }
 
@@ -31,13 +29,13 @@ class Hash extends NQPObject {
   }
 
   $$deletekey(key) {
-    if (this._SC !== undefined) this.$$scwb();
+    if (this.$$SC !== undefined) this.$$scwb();
     this.content.delete(key);
     return this;
   }
 
   $$clone() {
-    var clone = new Hash();
+    const clone = new Hash();
     this.content.forEach(function(value, key, map) {
       clone.content.set(key, value);
     });
@@ -53,7 +51,7 @@ class Hash extends NQPObject {
   }
 
   $$toObject() {
-    var ret = {};
+    const ret = {};
     this.content.forEach(function(value, key, map) {
       ret[key] = value;
     });
@@ -68,18 +66,6 @@ class Hash extends NQPObject {
     return new HashIter(this);
   }
 
-  // TODO: avoid copy and paste
-  $$scwb() {
-    if (compilingSCs.length == 0 || repossession.scwbDisableDepth || repossession.neverRepossess.get(this)) {
-      return;
-    }
-
-    if (compilingSCs[compilingSCs.length - 1] !== this._SC) {
-      var owned = this._SC.ownedObjects.get(this);
-      compilingSCs[compilingSCs.length - 1].repossessObject(owned === undefined ? this : owned);
-    }
-  }
-
   $$istype(ctx, type) {
     return 0;
   }
@@ -89,4 +75,6 @@ class Hash extends NQPObject {
   }
 };
 
+Hash.prototype.$$scwb = sixmodel.scwb;
+
 module.exports = Hash;
